Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(465)

Unified Diff: components/payments/core/journey_logger.h

Issue 2790253002: [Payments] Don't record CanMakePayment when in incognito mode. (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/payments/core/journey_logger.h
diff --git a/components/payments/core/journey_logger.h b/components/payments/core/journey_logger.h
index 5c35c0d7ecfa3015fcc4fd653f6d092183858a6d..3760ec64459df6ba8e4c8174639e836d3426913b 100644
--- a/components/payments/core/journey_logger.h
+++ b/components/payments/core/journey_logger.h
@@ -75,6 +75,9 @@ class JourneyLogger {
// Records the fact that the Payment Request was shown to the user.
void SetShowCalled();
+ // Records the fact that the Payment Request was done in an incognito tab.
+ void SetIsIncognito();
+
// Records the histograms for all the sections that were requested by the
// merchant and for the usage of the CanMakePayment method and its effect on
// the transaction. This method should be called when the Payment Request has
@@ -112,7 +115,8 @@ class JourneyLogger {
// merchant.
void RecordSectionSpecificStats(CompletionStatus completion_status);
// Records the metrics related the the CanMakePayment method.
void RecordCanMakePaymentStats(CompletionStatus completion_status);
// Records CanMakePayment's return value effect on whether the Payment Request
@@ -128,6 +132,7 @@ class JourneyLogger {
bool was_can_make_payments_used_;
bool could_make_payment_;
bool was_show_called_;
+ bool is_incognito_;
DISALLOW_COPY_AND_ASSIGN(JourneyLogger);
};
@@ -112,7 +115,8 @@ class JourneyLogger {
// merchant.
void RecordSectionSpecificStats(CompletionStatus completion_status);
- // Records the metrics related the the CanMakePayment method.
+ // Records the metrics related the the CanMakePayment method, if the Payment
+ // Request was not done in an incognito tab.
void RecordCanMakePaymentStats(CompletionStatus completion_status);
// Records CanMakePayment's return value effect on whether the Payment Request

Powered by Google App Engine
This is Rietveld 408576698